==> arla_0.35.6.orig.tar.gz: arla-0.35.6/xfs/linux/xfs/xfs_node.h <==
/*
 * Copyright (c) 1995 - 2000 Kungliga Tekniska Hgskolan
 * (Royal Institute of Technology, Stockholm, Sweden).
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * 3. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef _xfs_xnode_h
#define _xfs_xnode_h

#include <linux/types.h>
#include <linux/time.h>
#include <xfs/xfs_attr.h>
#include <xfs/xfs_message.h>

struct xfs_node {
    struct inode *vn;			/* inode we are associated with */
    struct dentry *data;		/* pointer to cache node */
    struct xfs_attr attr;		/* attribues of the node */
    u_int flags;			/* status of data (dirty), etc */
    u_int tokens;			/* what attr|data we have */
    xfs_handle handle;			/* the handle of the node */

    xfs_pag_t id[MAXRIGHTS];		/* cached rights for pags */
    u_char rights[MAXRIGHTS];
    u_char anonrights;			/* anonymous rights */

    struct list_head inactive_list;	/* put here when inactiveded,
					 * to avoid kmalloc */
    struct xfs_node *next;		/* list of all xfs nodes */
};

/*
 * useful macros
 */

#define DATA_FROM_VNODE(vp) DATA_FROM_XNODE(VNODE_TO_XNODE(vp))
#define DATA_FROM_XNODE(xp) ((xp)->data)

#define XNODE_TO_VNODE(xp) ((xp)->vn)
#define VNODE_TO_XNODE(vp) ((struct xfs_node *) (vp)->u.generic_ip)

#endif /* _xfs_xnode_h */

==> arla-0.35.11.tar.gz: arla-0.35.11/xfs/linux/xfs/xfs_node.h <==
/*
 * Copyright (c) 1995 - 2002 Kungliga Tekniska Hgskolan
 * (Royal Institute of Technology, Stockholm, Sweden).
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * 3. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 * 
 * Alternatively, this software may be distributed under the terms of the
 * GNU General Public License ("GPL").
 * 
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef _xfs_xnode_h
#define _xfs_xnode_h

#include <linux/types.h>
#include <linux/time.h>
#include <xfs/xfs_attr.h>
#include <xfs/xfs_message.h>

#define XN_HASHSIZE 10007

struct xfs_nodelist_head {
    struct list_head node_lists[XN_HASHSIZE];
};

struct xfs_nodelist {
    struct list_head node_list;		/* xfs nodes on this xfs-dev */
};

struct xfs_node {
    struct inode *vn;			/* inode we are associated with */
    struct dentry *data;		/* pointer to cache node */
    struct xfs_attr attr;		/* attribues of the node */
    u_int flags;			/* status of data (dirty), etc */
    u_int tokens;			/* what attr|data we have */
    xfs_handle handle;			/* the handle of the node */

    xfs_pag_t id[MAXRIGHTS];		/* cached rights for pags */
    u_char rights[MAXRIGHTS];
    u_char anonrights;			/* anonymous rights */

    struct list_head inactive_list;	/* put here when inactiveded,
					 * to avoid kmalloc */
    struct xfs_nodelist nodes;

};

struct xfs;

void	xn_insert(struct xfs_nodelist_head *, struct xfs_node *);
struct xfs_node * 
	xn_lookup(struct xfs_nodelist_head *, struct xfs_handle *);
void	xn_delete(struct xfs_nodelist_head *, struct xfs_node *);
int	xn_deletedp(struct xfs_node *);
void 	xn_purge(struct xfs *);
void	xn_init_head(struct xfs_nodelist_head *);

/*
 * useful macros
 */

#define DATA_FROM_VNODE(vp) DATA_FROM_XNODE(VNODE_TO_XNODE(vp))
#define DATA_FROM_XNODE(xp) ((xp)->data)

#define XNODE_TO_VNODE(xp) ((xp)->vn)
#define VNODE_TO_XNODE(vp) ((struct xfs_node *) (vp)->u.generic_ip)

#endif /* _xfs_xnode_h */
